@@ -1,21 +1,16 @@
 # -*- coding: utf-8 -*-
 import os
-from os.path import exists
 
-from omc.config import settings
-
-from omc.core.decorator import filecache
-
-from omc.common import CmdTaskMixin
-from omc.core import Resource
 import pkg_resources
 
-from omc.utils import JmxTermUtils
+from omc.common import CmdTaskMixin
+from omc.config import settings
+from omc.core import Resource
+from omc.core.decorator import filecache
 
 
 class Completion(Resource, CmdTaskMixin):
 
-
     def _description(self):
         return 'for resource completion'
 
@@ -32,9 +27,8 @@ class Completion(Resource, CmdTaskMixin):
 
         return "\n".join(results)
 
+
     def _run(self):
         if '--refresh' in self.context['all']:
             self._clean_completin_cache()
         print(self._get_resource_completion())
-
-
