@@ -1,4 +1,6 @@
 import os
+import shutil
+from distutils.dir_util import copy_tree
 
 
 def make_directory(dir):
@@ -12,3 +14,10 @@ def inplace_replace(file_name, old_string, new_string):
 
     with open(file_name, "w") as f:
         f.write(new_content)
+
+
+def copy(src, dest):
+    if os.path.isfile(src):
+        shutil.copy(src, dest)
+    else:
+        copy_tree(src, dest)
\ No newline at end of file
